@@ -1,11 +1,10 @@
-from typing import Iterable, Union, List
+from typing import Iterable, List
 
 import flask
 from flask import Flask
 
 from flask_sub_apps import helpers, config
-from flask_sub_apps.loader import ValidateFunction
-from flask_sub_apps.models import SubApp
+from flask_sub_apps.models import SubApp, ValidateFunction
 from flask_sub_apps.registry import AppRegistry
 
 logger = helpers.get_logger()
@@ -16,9 +15,6 @@ class FlaskSubApps:
         self,
         app: flask.Flask = None,
         installed_sub_apps: List[str] = None,
-        models_file: Union[str, List[str]] = None,
-        commands_file: Union[str, List[str]] = None,
-        routers_file: Union[str, List[str]] = None,
         registry: AppRegistry = None,
         is_valid_model: ValidateFunction = None,
         is_valid_command: ValidateFunction = None,
@@ -32,9 +28,6 @@ class FlaskSubApps:
 
         :param app: Flask app to initialize FlaskSubApps with.
         :param installed_sub_apps: List of sub apps to install.
-        :param models_file: Path to models file. List of paths is also accepted.
-        :param commands_file: Path to commands module. List of paths is also accepted.
-        :param routers_file: Path to routers module. List of paths is also accepted.
         :param registry: Instance of app registry to use.
         :param is_valid_model: Function to validate model.
         :param is_valid_command: Function to validate command.
@@ -50,14 +43,7 @@ class FlaskSubApps:
             is_valid_router=is_valid_router,
         )
         self._installed_sub_apps = installed_sub_apps or []
-        self.init_config(
-            models_file,
-            commands_file,
-            routers_file,
-            model_class,
-            router_class,
-            command_class,
-        )
+        self.init_config(model_class, router_class, command_class)
 
         if app is not None:
             self.init_app(app)
@@ -121,23 +107,8 @@ class FlaskSubApps:
         return iter(self._registry.get_sub_apps())
 
     @staticmethod
-    def init_config(
-        models_file: str,
-        commands_file: str,
-        routers_file: str,
-        model_class: type,
-        router_class: type,
-        command_class: type,
-    ):
-        """
-        Initialize config with user defined config files.
-        """
-        if models_file is not None:
-            config.MODELS_FILE = models_file
-        if commands_file is not None:
-            config.COMMANDS_FILE = commands_file
-        if routers_file is not None:
-            config.ROUTERS_FILE = routers_file
+    def init_config(model_class: type, router_class: type, command_class: type):
+        """Initialize config with user defined config files."""
         if model_class is not None:
             config.DBModel = model_class
         if router_class is not None:
