@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from types import ModuleType
-from typing import Set
+from typing import Set, Any, Callable
 
 from flask_sub_apps import config
 
@@ -16,9 +16,8 @@ class SubApp:
 
     api_prefix: str = ""
 
-    @property
-    def module_name(self):
-        return self.module.__name__
-
     def __str__(self):
-        return self.module_name
+        return self.name
+
+
+ValidateFunction = Callable[[Any], bool]
