@@ -1,10 +1,11 @@
 from typing import Optional, Type, Dict, List
 
 from flask import Flask
+from python_module_loader import PythonModuleLoader
 
+import type_validation
 from flask_sub_apps import helpers, config
-from flask_sub_apps.loader import ModuleLoader, ValidateFunction
-from flask_sub_apps.models import SubApp
+from flask_sub_apps.models import SubApp, ValidateFunction
 
 logger = helpers.get_logger()
 
@@ -20,7 +21,10 @@ class AppRegistry:
         is_valid_command: ValidateFunction = None,
         is_valid_router: ValidateFunction = None,
     ):
-        self._loader = ModuleLoader(is_valid_model, is_valid_command, is_valid_router)
+        self.is_valid_model = is_valid_model or type_validation.is_valid_model
+        self.is_valid_command = is_valid_command or type_validation.is_valid_command
+        self.is_valid_router = is_valid_router or type_validation.is_valid_router
+        self._loader = PythonModuleLoader()
 
     def get_sub_apps(self) -> List[SubApp]:
         """
@@ -38,9 +42,14 @@ class AppRegistry:
         :return: Sub-app with modules or None if failed to register.
         """
         try:
-            sub_app = self._loader.load_sub_app(module_name)
-
-            self.sub_apps[sub_app.module_name] = sub_app
+            self._loader.load(module_name)
+            sub_app = SubApp(
+                name=module_name,
+                models=list(self._loader.find_objects(self.is_valid_model)),
+                commands=list(self._loader.find_objects(self.is_valid_command)),
+                routers=list(self._loader.find_objects(self.is_valid_router)),
+            )
+            self.sub_apps[module_name] = sub_app
             self.register_routers(app)
             self.register_commands(app)
             return sub_app
@@ -69,17 +78,17 @@ class AppRegistry:
 
     def get_routers(self) -> List[config.Router]:
         """Get all registered routers."""
-        return [view for sub_app in self.get_sub_apps() for view in sub_app.routers]
+        return [router for router in self._loader.find_objects([self.is_valid_router])]
 
     def get_commands(self) -> List[config.Command]:
         """Get all registered commands."""
         return [
-            command for sub_app in self.get_sub_apps() for command in sub_app.commands
+            command for command in self._loader.find_objects([self.is_valid_command])
         ]
 
     def get_models(self) -> List[Type[config.DBModel]]:
         """Get all registered models."""
-        return [model for sub_app in self.get_sub_apps() for model in sub_app.models]
+        return [model for model in self._loader.find_objects([self.is_valid_model])]
 
     def get_model(self, model_name: str) -> Optional[Type[config.DBModel]]:
         """
